@@ -223,7 +223,8 @@ function(fit, d = "best", pl = -Inf, pu = Inf, ql = NA, qu = NA, sf = 3, ex = 1,
 	p1 <- ggplot(df1, aes(x = x, y = fx)) +
 	  geom_line(size = lwd) +
 	  xlim(pl, pu) + 
-	  labs(title = dist.title, x = xlab, y = ylab )
+	  labs(title = dist.title, x = xlab, y = ylab )+
+	  theme(plot.title = element_text(hjust = 0.5))
 	if(is.na(ql) == F  ){
 	  p1 <- p1 + geom_ribbon(data = subset(df1, x<=x.q1), 
 	                         aes(ymax = fx, ymin = 0),
